]> git.tuebingen.mpg.de Git - paraslash.git/blobdiff - list.h
build: Rename all_objs -> dep_objs.
[paraslash.git] / list.h
diff --git a/list.h b/list.h
index 9056f1f7f4c72a048a2dd645bba076baa9d9b667..78c302fa322fe6bc2dae2926e95e58189c10c944 100644 (file)
--- a/list.h
+++ b/list.h
@@ -25,9 +25,11 @@ struct list_head {
 #define INITIALIZED_LIST_HEAD(name) struct list_head name = {&(name), &(name)}
 
 /** This must be called before using any other list functions. */
-#define INIT_LIST_HEAD(ptr) do { \
-       (ptr)->next = (ptr); (ptr)->prev = (ptr); \
-} while (0)
+static inline void init_list_head(struct list_head *head)
+{
+       head->next = head;
+       head->prev = head;
+}
 
 /**
  * Insert a new entry after the specified head.
@@ -125,7 +127,7 @@ static inline int list_is_singular(const struct list_head *head)
 /**
  * Iterate over a list.
  *
* \param pos A list head pointer which serves as the iterator.
  * \param head The head of the list.
  * \param member The name of the list head member within the structure.
  */
@@ -137,8 +139,8 @@ static inline int list_is_singular(const struct list_head *head)
 /**
  * Iterate over list, safe against removal of list entry.
  *
* \param pos The iterator.
* \param n A list head pointer which is used as temporary storage.
  * \param head The head of the list.
  * \param member The name of the list head member within the structure.
  */
@@ -125,7 +127,7 @@ static inline int list_is_singular(const struct list_head *head)
  * Iterate over a list.
  *
- * \param pos A list head pointer which serves as the iterator.
+ * \param pos A struct pointer which serves as the iterator.
  * \param head The head of the list.
  * \param member The name of the list head member within the structure.
@@ -137,8 +139,8 @@ static inline int list_is_singular(const struct list_head *head)
  * Iterate over list, safe against removal of list entry.
  *
- * \param pos The iterator.
- * \param n A list head pointer which is used as temporary storage.
+ * \param pos The iterator struct pointer.
+ * \param n A second struct pointer which is used as temporary storage.
  * \param head The head of the list.
  * \param member The name of the list head member within the structure.